Page 32 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 32

Home

    Weishaupt, through his organizing ability, was able to
    make the Illuminati one of the most effective instruments

    of evil that has ever been uncovered. Using the
    philosophy that "the end justifies the means," his
    methods became a model for world revolution.

    Eventually, the Order became suspect by the
    government of Bavaria, resulting in an investigation by a
    Bavarian Court of Inquiry in 1783. An event that led to
    exposure of the subversive nature of the Order was the
    untimely death of one of its members, an evangelist
    preacher named Lanze, who, while on a mission to
    Silesia, was struck down by lightning. Instructions found
    on his body resulted in a raid on the houses of two of the
    leading members of the Order. Here much mcriminating
    evidence was uncovered, among which was a list of

    Although Weishaupt was banished from Bavaria, and
    the Order was officially suppressed, the Order simply
    went underground and emerged as a network of Reading
    Societies throughout Germany. The goal of this network
    was to monopolize the writing, publication, reviewing,
    and distribution of all literature, as a means of controlling

    From the very beginning, the Illuminati was a secret
    society within a secret society, beginning in the Masonic
    Lodge Theodore of Munich, Germany of which
    Weishaupt was a member. It was his plan to use the

    27

    The Illuminati

    Using the methods of earlier secret societies,

    poisons.

    the minds of the readers.